@@ -5,6 +5,7 @@ import json
 
 from aiohttp.client_exceptions import ClientError
 
+from nonebot import get_driver
 from nonebot.params import State, ArgPlainText, Arg, CommandArg
 from nonebot.plugin import on_command, on_message
 from nonebot.rule import to_me
@@ -21,6 +22,8 @@ from .yandex import get_des as get_des_yandex
 
 from .utils import limiter
 
+global_config = get_driver().config
+record_priority = getattr(global_config, "record_priority", 99)
 
 async def get_des(url: str, mode: str):
     """
@@ -52,7 +55,7 @@ setu = on_command("搜图", aliases={"search"}, rule=to_me())
 
 
 @setu.handle()
-async def handle_first_receive(event: MessageEvent, state: T_State = State(), setu: Message = CommandArg()):
+async def handle_first_receive(event: MessageEvent, state: T_State, setu: Message = CommandArg()):
     if setu:
         state["setu"] = setu
 
@@ -120,7 +123,7 @@ async def check_pic(bot: Bot, event: MessageEvent, state: T_State = State()) ->
         return False
 
 
-notice_pic = on_message(check_pic)
+notice_pic = on_message(check_pic, block=False, priority=record_priority)
 
 
 @notice_pic.handle()
